@@ -3,8 +3,8 @@ Collection of Two-View-Geometry Functions
 """
 
 # global
+import ivy as _ivy
 import ivy_mech as _ivy_mech
-from ivy.framework_handler import get_framework as _get_framework
 
 # local
 from ivy_vision import projective_geometry as _ivy_pg
@@ -13,7 +13,7 @@ from ivy_vision import single_view_geometry as _ivy_svg
 MIN_DENOMINATOR = 1e-12
 
 
-def pixel_to_pixel_coords(pixel_coords1, cam1to2_full_mat, batch_shape=None, image_dims=None, dev=None, f=None):
+def pixel_to_pixel_coords(pixel_coords1, cam1to2_full_mat, batch_shape=None, image_dims=None, dev_str=None):
     """
     Transform depth scaled homogeneous pixel co-ordinates image in first camera frame
     :math:`\mathbf{X}_{p1}\in\mathbb{R}^{h×w×3}` to depth scaled homogeneous pixel co-ordinates image in second camera
@@ -29,37 +29,33 @@ def pixel_to_pixel_coords(pixel_coords1, cam1to2_full_mat, batch_shape=None, ima
     :type batch_shape: sequence of ints, optional
     :param image_dims: Image dimensions. Inferred from inputs in None.
     :type image_dims: sequence of ints, optional
-    :param dev: device on which to create the array 'cuda:0', 'cuda:1', 'cpu' etc. Same as x if None.
-    :type dev: str, optional
-    :param f: Machine learning library. Inferred from inputs if None.
-    :type f: ml_framework, optional
+    :param dev_str: device on which to create the array 'cuda:0', 'cuda:1', 'cpu' etc. Same as x if None.
+    :type dev_str: str, optional
     :return: Depth scaled homogeneous pixel co-ordinates image in frame 2 *[batch_shape,h,w,3]*
     """
 
-    f = _get_framework(pixel_coords1, f=f)
-
     if batch_shape is None:
         batch_shape = pixel_coords1.shape[:-3]
 
     if image_dims is None:
         image_dims = pixel_coords1.shape[-3:-1]
 
-    if dev is None:
-        dev = f.get_device(pixel_coords1)
+    if dev_str is None:
+        dev_str = _ivy.dev_str(pixel_coords1)
 
     # shapes as list
     batch_shape = list(batch_shape)
     image_dims = list(image_dims)
 
     # BS x H x W x 4
-    pixel_coords_homo = f.concatenate((pixel_coords1,
-                                          f.ones(batch_shape + image_dims + [1], dev=dev)), -1)
+    pixel_coords_homo = _ivy.concatenate((pixel_coords1,
+                                          _ivy.ones(batch_shape + image_dims + [1], dev_str=dev_str)), -1)
 
     # BS x H x W x 3
-    return _ivy_pg.transform(pixel_coords_homo, cam1to2_full_mat, batch_shape, image_dims, f=f)
+    return _ivy_pg.transform(pixel_coords_homo, cam1to2_full_mat, batch_shape, image_dims)
 
 
-def cam_to_cam_coords(cam_coords1, cam1to2_ext_mat, batch_shape=None, image_dims=None, dev=None, f=None):
+def cam_to_cam_coords(cam_coords1, cam1to2_ext_mat, batch_shape=None, image_dims=None, dev_str=None):
     """
     Transform camera-centric homogeneous co-ordinates image for camera 1 :math:`\mathbf{X}_{c1}\in\mathbb{R}^{h×w×4}` to
     camera-centric homogeneous co-ordinates image for camera 2 :math:`\mathbf{X}_{c2}\in\mathbb{R}^{h×w×4}`.\n
@@ -73,36 +69,32 @@ def cam_to_cam_coords(cam_coords1, cam1to2_ext_mat, batch_shape=None, image_dims
     :type batch_shape: sequence of ints, optional
     :param image_dims: Image dimensions. Inferred from inputs in None.
     :type image_dims: sequence of ints, optional
-    :param dev: device on which to create the array 'cuda:0', 'cuda:1', 'cpu' etc. Same as x if None.
-    :type dev: str, optional
-    :param f: Machine learning library. Inferred from inputs if None.
-    :type f: ml_framework, optional
+    :param dev_str: device on which to create the array 'cuda:0', 'cuda:1', 'cpu' etc. Same as x if None.
+    :type dev_str: str, optional
     :return: Depth scaled homogeneous pixel co-ordinates image in frame 2 *[batch_shape,h,w,3]*
     """
 
-    f = _get_framework(cam_coords1, f=f)
-
     if batch_shape is None:
         batch_shape = cam_coords1.shape[:-3]
 
     if image_dims is None:
         image_dims = cam_coords1.shape[-3:-1]
 
-    if dev is None:
-        dev = f.get_device(cam_coords1)
+    if dev_str is None:
+        dev_str = _ivy.dev_str(cam_coords1)
 
     # shapes as list
     batch_shape = list(batch_shape)
     image_dims = list(image_dims)
 
     # BS x H x W x 3
-    cam_coords2 = _ivy_pg.transform(cam_coords1, cam1to2_ext_mat, batch_shape, image_dims, f=f)
+    cam_coords2 = _ivy_pg.transform(cam_coords1, cam1to2_ext_mat, batch_shape, image_dims)
 
     # BS x H x W x 4
-    return f.concatenate((cam_coords2, f.ones(batch_shape + image_dims + [1], dev=dev)), -1)
+    return _ivy.concatenate((cam_coords2, _ivy.ones(batch_shape + image_dims + [1], dev_str=dev_str)), -1)
 
 
-def sphere_to_sphere_coords(sphere_coords1, cam1to2_ext_mat, batch_shape=None, image_dims=None, f=None):
+def sphere_to_sphere_coords(sphere_coords1, cam1to2_ext_mat, batch_shape=None, image_dims=None):
     """
     Convert camera-centric ego-sphere polar co-ordinates image in frame 1 :math:`\mathbf{S}_{c1}\in\mathbb{R}^{h×w×3}`
     to camera-centric ego-sphere polar co-ordinates image in frame 2 :math:`\mathbf{S}_{c2}\in\mathbb{R}^{h×w×3}`.\n
@@ -116,13 +108,9 @@ def sphere_to_sphere_coords(sphere_coords1, cam1to2_ext_mat, batch_shape=None, i
     :type batch_shape: sequence of ints, optional
     :param image_dims: Image dimensions. Inferred from inputs in None.
     :type image_dims: sequence of ints, optional
-    :param f: Machine learning library. Inferred from inputs if None.
-    :type f: ml_framework, optional
     :return: Camera-centric ego-sphere polar co-ordinates image in frame 2 *[batch_shape,h,w,3]*
     """
 
-    f = _get_framework(sphere_coords1, f=f)
-
     if batch_shape is None:
         batch_shape = sphere_coords1.shape[:-3]
 
@@ -134,15 +122,15 @@ def sphere_to_sphere_coords(sphere_coords1, cam1to2_ext_mat, batch_shape=None, i
     image_dims = list(image_dims)
 
     # BS x H x W x 4
-    cam_coords1 = _ivy_svg.sphere_to_cam_coords(sphere_coords1, batch_shape, image_dims, f=f)
+    cam_coords1 = _ivy_svg.sphere_to_cam_coords(sphere_coords1, batch_shape, image_dims)
     cam_coords2 = cam_to_cam_coords(cam_coords1, cam1to2_ext_mat, batch_shape, image_dims)
 
     # BS x H x W x 3
-    return _ivy_svg.cam_to_sphere_coords(cam_coords2, batch_shape, image_dims, f=f)
+    return _ivy_svg.cam_to_sphere_coords(cam_coords2, batch_shape, image_dims)
 
 
 def angular_pixel_to_angular_pixel_coords(angular_pixel_coords1, cam1to2_ext_mat, pixels_per_degree, batch_shape=None,
-                                          image_dims=None, f=None):
+                                          image_dims=None):
     """
     Convert angular pixel co-ordinates image in frame 1 :math:`\mathbf{A}_{p1}\in\mathbb{R}^{h×w×3}` to angular pixel
     co-ordinates image in frame 2 :math:`\mathbf{A}_{p2}\in\mathbb{R}^{h×w×3}`.\n
@@ -158,13 +146,9 @@ def angular_pixel_to_angular_pixel_coords(angular_pixel_coords1, cam1to2_ext_mat
     :type batch_shape: sequence of ints, optional
     :param image_dims: Image dimensions. Inferred from inputs in None.
     :type image_dims: sequence of ints, optional
-    :param f: Machine learning library. Inferred from inputs if None.
-    :type f: ml_framework, optional
     :return: Camera-centric ego-sphere polar co-ordinates image in frame 2 *[batch_shape,h,w,3]*
     """
 
-    f = _get_framework(angular_pixel_coords1, f=f)
-
     if batch_shape is None:
         batch_shape = angular_pixel_coords1.shape[:-3]
 
@@ -176,17 +160,16 @@ def angular_pixel_to_angular_pixel_coords(angular_pixel_coords1, cam1to2_ext_mat
     image_dims = list(image_dims)
 
     # BS x H x W x 3
-    sphere_coords1 = _ivy_svg.angular_pixel_to_sphere_coords(angular_pixel_coords1, pixels_per_degree, f=f)
+    sphere_coords1 = _ivy_svg.angular_pixel_to_sphere_coords(angular_pixel_coords1, pixels_per_degree)
 
     # BS x H x W x 3
     sphere_coords2 = sphere_to_sphere_coords(sphere_coords1, cam1to2_ext_mat, batch_shape, image_dims)
 
     # BS x H x W x 3
-    return _ivy_svg.sphere_to_angular_pixel_coords(sphere_coords2, pixels_per_degree, f=f)
+    return _ivy_svg.sphere_to_angular_pixel_coords(sphere_coords2, pixels_per_degree)
 
 
-def get_fundamental_matrix(full_mat1, full_mat2, camera_center1=None, pinv_full_mat1=None, batch_shape=None, dev=None,
-                           f=None):
+def get_fundamental_matrix(full_mat1, full_mat2, camera_center1=None, pinv_full_mat1=None, batch_shape=None, dev_str=None):
     """
     Compute fundamental matrix :math:`\mathbf{F}\in\mathbb{R}^{3×3}` between two cameras, given their extrinsic
     matrices :math:`\mathbf{E}_1\in\mathbb{R}^{3×4}` and :math:`\mathbf{E}_2\in\mathbb{R}^{3×4}`.\n
@@ -203,46 +186,43 @@ def get_fundamental_matrix(full_mat1, full_mat2, camera_center1=None, pinv_full_
     :type pinv_full_mat1: array, optional
     :param batch_shape: Shape of batch. Inferred from inputs if None.
     :type batch_shape: sequence of ints, optional
-    :param dev: device on which to create the array 'cuda:0', 'cuda:1', 'cpu' etc. Same as x if None.
-    :type dev: str, optional
-    :param f: Machine learning library. Inferred from inputs if None.
-    :type f: ml_framework, optional
+    :param dev_str: device on which to create the array 'cuda:0', 'cuda:1', 'cpu' etc. Same as x if None.
+    :type dev_str: str, optional
     :return: Fundamental matrix connecting frames 1 and 2 *[batch_shape,3,3]*
     """
 
-    f = _get_framework(full_mat1, f=f)
-
     if batch_shape is None:
         batch_shape = full_mat1.shape[:-2]
 
-    if dev is None:
-        dev = f.get_device(full_mat1)
+    if dev_str is None:
+        dev_str = _ivy.dev_str(full_mat1)
 
     # shapes as list
     batch_shape = list(batch_shape)
 
     if camera_center1 is None:
-        inv_full_mat1 = f.inv(_ivy_mech.make_transformation_homogeneous(full_mat1, batch_shape, dev, f=f))[..., 0:3, :]
-        camera_center1 = _ivy_svg.inv_ext_mat_to_camera_center(inv_full_mat1, f=f)
+        inv_full_mat1 = _ivy.inv(_ivy_mech.make_transformation_homogeneous(full_mat1, batch_shape, dev_str))[..., 0:3, :]
+        camera_center1 = _ivy_svg.inv_ext_mat_to_camera_center(inv_full_mat1)
 
     if pinv_full_mat1 is None:
-        pinv_full_mat1 = f.pinv(full_mat1)
+        pinv_full_mat1 = _ivy.pinv(full_mat1)
 
     # BS x 4 x 1
-    camera_center1_homo = f.concatenate((camera_center1, f.ones(batch_shape + [1, 1], dev=dev)), -2)
+    camera_center1_homo = _ivy.concatenate((camera_center1, _ivy.ones(batch_shape + [1, 1], dev_str=dev_str)), -2)
 
     # BS x 3
-    e2 = f.matmul(full_mat2, camera_center1_homo)[..., -1]
+    e2 = _ivy.matmul(full_mat2, camera_center1_homo)[..., -1]
 
     # BS x 3 x 3
-    e2_skew_symmetric = f.linalg.vector_to_skew_symmetric_matrix(e2, batch_shape)
+    e2_skew_symmetric = _ivy.linalg.vector_to_skew_symmetric_matrix(e2)
 
     # BS x 3 x 3
-    return f.matmul(e2_skew_symmetric, f.matmul(full_mat2, pinv_full_mat1))
+    return _ivy.matmul(e2_skew_symmetric, _ivy.matmul(full_mat2, pinv_full_mat1))
 
 
+# noinspection PyUnresolvedReferences
 def closest_mutual_points_along_two_skew_rays(camera_centers, world_ray_vectors, batch_shape=None, image_dims=None,
-                                              dev=None, f=None):
+                                              dev_str=None):
     """
     Compute closest mutual homogeneous co-ordinates :math:`\mathbf{x}_{1,i,j}\in\mathbb{R}^{4}` and
     :math:`\mathbf{x}_{2,i,j}\in\mathbb{R}^{4}` along two world-centric rays
@@ -263,23 +243,19 @@ def closest_mutual_points_along_two_skew_rays(camera_centers, world_ray_vectors,
     :type batch_shape: sequence of ints, optional
     :param image_dims: Image dimensions. Inferred from inputs in None.
     :type image_dims: sequence of ints, optional
-    :param dev: device on which to create the array 'cuda:0', 'cuda:1', 'cpu' etc. Same as x if None.
-    :type dev: str, optional
-    :param f: Machine learning library. Inferred from inputs if None.
-    :type f: ml_framework, optional
+    :param dev_str: device on which to create the array 'cuda:0', 'cuda:1', 'cpu' etc. Same as x if None.
+    :type dev_str: str, optional
     :return: Closest mutual points image *[batch_shape,2,h,w,4]*
     """
 
-    f = _get_framework(camera_centers, f=f)
-
     if batch_shape is None:
         batch_shape = world_ray_vectors.shape[:-4]
 
     if image_dims is None:
         image_dims = world_ray_vectors.shape[-3:-1]
 
-    if dev is None:
-        dev = f.get_device(camera_centers)
+    if dev_str is None:
+        dev_str = _ivy.dev_str(camera_centers)
 
     # shapes as list
     batch_shape = list(batch_shape)
@@ -290,8 +266,8 @@ def closest_mutual_points_along_two_skew_rays(camera_centers, world_ray_vectors,
     camera_center1 = camera_centers[..., 1, :, :]
 
     # BS x 1 x 1 x 3
-    cam1_to_cam2 = f.reshape(camera_center1 - camera_center0, batch_shape + [1, 1, 3])
-    cam2_to_cam1 = f.reshape(camera_center0 - camera_center1, batch_shape + [1, 1, 3])
+    cam1_to_cam2 = _ivy.reshape(camera_center1 - camera_center0, batch_shape + [1, 1, 3])
+    cam2_to_cam1 = _ivy.reshape(camera_center0 - camera_center1, batch_shape + [1, 1, 3])
 
     # BS x 2 x H x W x 3
     ds = world_ray_vectors
@@ -299,48 +275,48 @@ def closest_mutual_points_along_two_skew_rays(camera_centers, world_ray_vectors,
     # BS x H x W x 3
     ds0 = ds[..., 0, :, :, :]
     ds1 = ds[..., 1, :, :, :]
-    n = f.cross(ds0, ds1)
-    n1 = f.cross(ds0, n)
-    n2 = f.cross(ds1, n)
+    n = _ivy.cross(ds0, ds1)
+    n1 = _ivy.cross(ds0, n)
+    n2 = _ivy.cross(ds1, n)
 
     # BS x 1 x H x W
-    t1 = f.expand_dims(f.reduce_sum(cam1_to_cam2 * n2, -1) / (
-            f.reduce_sum(ds0 * n2, -1) + MIN_DENOMINATOR), -3)
-    t2 = f.expand_dims(f.reduce_sum(cam2_to_cam1 * n1, -1) / (
-            f.reduce_sum(ds1 * n1, -1) + MIN_DENOMINATOR), -3)
+    t1 = _ivy.expand_dims(_ivy.reduce_sum(cam1_to_cam2 * n2, -1) / (
+            _ivy.reduce_sum(ds0 * n2, -1) + MIN_DENOMINATOR), -3)
+    t2 = _ivy.expand_dims(_ivy.reduce_sum(cam2_to_cam1 * n1, -1) / (
+            _ivy.reduce_sum(ds1 * n1, -1) + MIN_DENOMINATOR), -3)
 
     # BS x 2 x H x W
-    ts = f.expand_dims(f.concatenate((t1, t2), -3), -1)
+    ts = _ivy.expand_dims(_ivy.concatenate((t1, t2), -3), -1)
 
     # BS x 2 x H x W x 3
-    world_coords = f.reshape(camera_centers[..., 0], batch_shape + [2, 1, 1, 3]) + ts * world_ray_vectors
+    world_coords = _ivy.reshape(camera_centers[..., 0], batch_shape + [2, 1, 1, 3]) + ts * world_ray_vectors
 
     # BS x 2 x H x W x 4
-    return f.concatenate((world_coords, f.ones(batch_shape + [2] + image_dims + [1], dev=dev)), -1)
+    return _ivy.concatenate((world_coords, _ivy.ones(batch_shape + [2] + image_dims + [1], dev_str=dev_str)), -1)
 
 
 def _triangulate_depth_by_closest_mutual_points(pixel_coords, full_mats, inv_full_mats, camera_centers, batch_shape,
-                                                image_dims, f):
+                                                image_dims):
 
     # single view geom batch shape
     svg_batch_shape = batch_shape + [2]
 
     # BS x 2 x H x W x 3
     world_rays_flat = _ivy_svg.pixel_coords_to_world_ray_vectors(pixel_coords, inv_full_mats, camera_centers,
-                                                                 svg_batch_shape, image_dims, f=f)
+                                                                 svg_batch_shape, image_dims)
 
     # BS x 2 x H x W x 3
-    world_rays = f.reshape(world_rays_flat, svg_batch_shape + image_dims + [3])
+    world_rays = _ivy.reshape(world_rays_flat, svg_batch_shape + image_dims + [3])
 
     # BS x 2 x H x W x 4
-    world_points = closest_mutual_points_along_two_skew_rays(camera_centers, world_rays, batch_shape, image_dims, f=f)
+    world_points = closest_mutual_points_along_two_skew_rays(camera_centers, world_rays, batch_shape, image_dims)
 
     # BS x H x W x 3
     return _ivy_svg.world_to_pixel_coords(world_points[..., 0, :, :, :], full_mats[..., 0, :, :],
-                                          batch_shape, image_dims, f=f)
+                                          batch_shape, image_dims)
 
 
-def _triangulate_depth_by_homogeneous_dlt(pixel_coords, full_mats, _, _1, batch_shape, image_dims, f):
+def _triangulate_depth_by_homogeneous_dlt(pixel_coords, full_mats, _, _1, batch_shape, image_dims):
 
     # num batch dims
     num_batch_dims = len(batch_shape)
@@ -353,38 +329,38 @@ def _triangulate_depth_by_homogeneous_dlt(pixel_coords, full_mats, _, _1, batch_
     P_dash = full_mats[..., 1, :, :]
 
     # BS x (HxW) x 4
-    p1T = f.tile(P[..., 0:1, :], [1] * num_batch_dims + [image_dims[0] * image_dims[1], 1])
-    p2T = f.tile(P[..., 1:2, :], [1] * num_batch_dims + [image_dims[0] * image_dims[1], 1])
-    p3T = f.tile(P[..., 2:3, :], [1] * num_batch_dims + [image_dims[0] * image_dims[1], 1])
+    p1T = _ivy.tile(P[..., 0:1, :], [1] * num_batch_dims + [image_dims[0] * image_dims[1], 1])
+    p2T = _ivy.tile(P[..., 1:2, :], [1] * num_batch_dims + [image_dims[0] * image_dims[1], 1])
+    p3T = _ivy.tile(P[..., 2:3, :], [1] * num_batch_dims + [image_dims[0] * image_dims[1], 1])
 
-    p_dash_1T = f.tile(P_dash[..., 0:1, :], [1] * num_batch_dims + [image_dims[0] * image_dims[1], 1])
-    p_dash_2T = f.tile(P_dash[..., 1:2, :], [1] * num_batch_dims + [image_dims[0] * image_dims[1], 1])
-    p_dash_3T = f.tile(P_dash[..., 2:3, :], [1] * num_batch_dims + [image_dims[0] * image_dims[1], 1])
+    p_dash_1T = _ivy.tile(P_dash[..., 0:1, :], [1] * num_batch_dims + [image_dims[0] * image_dims[1], 1])
+    p_dash_2T = _ivy.tile(P_dash[..., 1:2, :], [1] * num_batch_dims + [image_dims[0] * image_dims[1], 1])
+    p_dash_3T = _ivy.tile(P_dash[..., 2:3, :], [1] * num_batch_dims + [image_dims[0] * image_dims[1], 1])
 
     # BS x (WxH) x 1
-    x = f.reshape(pixel_coords_normalized[..., 0, :, :, 0], batch_shape + [-1, 1])
-    y = f.reshape(pixel_coords_normalized[..., 0, :, :, 1], batch_shape + [-1, 1])
-    x_dash = f.reshape(pixel_coords_normalized[..., 1, :, :, 0], batch_shape + [-1, 1])
-    y_dash = f.reshape(pixel_coords_normalized[..., 1, :, :, 1], batch_shape + [-1, 1])
+    x = _ivy.reshape(pixel_coords_normalized[..., 0, :, :, 0], batch_shape + [-1, 1])
+    y = _ivy.reshape(pixel_coords_normalized[..., 0, :, :, 1], batch_shape + [-1, 1])
+    x_dash = _ivy.reshape(pixel_coords_normalized[..., 1, :, :, 0], batch_shape + [-1, 1])
+    y_dash = _ivy.reshape(pixel_coords_normalized[..., 1, :, :, 1], batch_shape + [-1, 1])
 
     # BS x (HxW) x 1 x 4
-    A_row1 = f.expand_dims(x * p3T - p1T, -2)
-    A_row2 = f.expand_dims(y * p3T - p2T, -2)
-    A_row3 = f.expand_dims(x_dash * p_dash_3T - p_dash_1T, -2)
-    A_row4 = f.expand_dims(y_dash * p_dash_3T - p_dash_2T, -2)
+    A_row1 = _ivy.expand_dims(x * p3T - p1T, -2)
+    A_row2 = _ivy.expand_dims(y * p3T - p2T, -2)
+    A_row3 = _ivy.expand_dims(x_dash * p_dash_3T - p_dash_1T, -2)
+    A_row4 = _ivy.expand_dims(y_dash * p_dash_3T - p_dash_2T, -2)
 
     # BS x (HxW) x 4 x 4
-    A = f.concatenate((A_row1, A_row2, A_row3, A_row4), -2)
+    A = _ivy.concatenate((A_row1, A_row2, A_row3, A_row4), -2)
 
     # BS x (HxW) x 4
-    X = _ivy_pg.solve_homogeneous_dlt(A, f=f)
+    X = _ivy_pg.solve_homogeneous_dlt(A)
 
     # BS x W x H x 4
-    coords_wrt_world_homo_unscaled = f.reshape(X, batch_shape + image_dims + [4])
+    coords_wrt_world_homo_unscaled = _ivy.reshape(X, batch_shape + image_dims + [4])
     coords_wrt_world = coords_wrt_world_homo_unscaled / (coords_wrt_world_homo_unscaled[..., -1:] + MIN_DENOMINATOR)
 
     # BS x W x H x 3
-    return _ivy_svg.world_to_pixel_coords(coords_wrt_world, full_mats[..., 0, :, :], batch_shape, image_dims, f=f)
+    return _ivy_svg.world_to_pixel_coords(coords_wrt_world, full_mats[..., 0, :, :], batch_shape, image_dims)
 
 
 TRI_METHODS = {'cmp': _triangulate_depth_by_closest_mutual_points,
@@ -392,7 +368,7 @@ TRI_METHODS = {'cmp': _triangulate_depth_by_closest_mutual_points,
 
 
 def triangulate_depth(pixel_coords, full_mats, inv_full_mats=None, camera_centers=None, method='cmp', batch_shape=None,
-                      image_dims=None, f=None):
+                      image_dims=None):
     """
     Triangulate depth in frame 1, returning depth scaled homogeneous pixel co-ordinate image
     :math:`\mathbf{X}\in\mathbb{R}^{h×w×3}` in frame 1.\n
@@ -411,13 +387,9 @@ def triangulate_depth(pixel_coords, full_mats, inv_full_mats=None, camera_center
     :type batch_shape: sequence of ints, optional
     :param image_dims: Image dimensions. Inferred from inputs in None.
     :type image_dims: sequence of ints, optional
-    :param f: Machine learning library. Inferred from inputs if None.
-    :type f: ml_framework, optional
     :return: Depth scaled homogeneous pixel co-ordinates image in frame 1 *[batch_shape,h,w,3]*
     """
 
-    f = _get_framework(pixel_coords, f=f)
-
     if batch_shape is None:
         batch_shape = pixel_coords.shape[:-4]
 
@@ -431,13 +403,13 @@ def triangulate_depth(pixel_coords, full_mats, inv_full_mats=None, camera_center
     if method == 'cmt':
 
         if inv_full_mats is None:
-            inv_full_mats = f.inv(_ivy_mech.make_transformation_homogeneous(
-                full_mats, batch_shape + [2], f=f))[..., 0:3, :]
+            inv_full_mats = _ivy.inv(_ivy_mech.make_transformation_homogeneous(
+                full_mats, batch_shape + [2]))[..., 0:3, :]
 
         if camera_centers is None:
-            camera_centers = _ivy_svg.inv_ext_mat_to_camera_center(inv_full_mats, f=f)
+            camera_centers = _ivy_svg.inv_ext_mat_to_camera_center(inv_full_mats)
 
     try:
-        return TRI_METHODS[method](pixel_coords, full_mats, inv_full_mats, camera_centers, batch_shape, image_dims, f)
+        return TRI_METHODS[method](pixel_coords, full_mats, inv_full_mats, camera_centers, batch_shape, image_dims)
     except KeyError:
         raise Exception('Triangulation method must be one of [cmp|dlt], but found {}'.format(method))
